<?php

namespace Onestartup\Shop\Controller;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Yajra\Datatables\Datatables;
use Onestartup\Shop\Model\ProductShop as Product;
use Onestartup\Shop\Model\ProductCategoryShop as Category;

class CartController extends Controller
{
   public function __construct()
   {
       if (!\Session::has('cart')) {
           \Session::put('cart', array());
       }
   }

   public function show()
   {
        $total = $this->total();
        $cart = \Session::get('cart');

        return view('shop-public::show-cart')
            ->with('cart', $cart)
            ->with('total', $total);
   }

   public function add(Product $product)
   {
        $cart = \Session::get('cart');
        $quantity = 1;

        
        if (isset($cart[$product->slug])) {
            $quantity = $cart[$product->slug]->quantity + 1;
        }

        $product->quantity = $quantity;
        $cart[$product->slug] = $product;

        \Session::put('cart', $cart);

        return redirect()->route('cart.show');
   }


    public function remove(Product $product)
    {
        $cart = \Session::get('cart');

        if (!isset($cart[$product->slug])) {
            return redirect()->route('cart.show');
        }

        unset($cart[$product->slug]);
        \Session::put('cart', $cart);
        return redirect()->route('cart.show');
    }
 
    public function update(Product $product, $quantity)
    {
        if ($quantity <= 0) {
            return redirect()->back();
        }
        $cart = \Session::get('cart');
        if (!isset($cart[$product->slug])) {
            return redirect()->route('cart.show');
        }
        $cart[$product->slug]->quantity = $quantity;
        \Session::put('cart', $cart);
        return redirect()->route('cart.show');
    }

    public function trash()
    {
        \Session::forget('cart');
        return redirect()->route('cart.show');
    }


    private function total()
    {
        $cart = \Session::get('cart');
        $total = 0;
        foreach($cart as $product){
            $total += $product->infoSale->sale_price * $product->quantity;
        }
        return $total;
    }


}
